@@ -1446,7 +1446,7 @@ append_message (MailStub *stub, const char *folder_name, guint32 flags,
 	MailStubExchange *mse = MAIL_STUB_EXCHANGE (stub);
 	MailStubExchangeFolder *mfld;
 	E2kHTTPStatus status;
-	char *ru_header, *repl_uid, *location;
+	char *ru_header = NULL, *repl_uid, *location = NULL;
 
 	mfld = folder_from_name (mse, folder_name, MAPI_ACCESS_CREATE_CONTENTS, FALSE);
 	if (!mfld)
@@ -2725,7 +2725,6 @@ unsubscribe_folder (MailStub *stub, const char *folder_name)
 		g_free (path);
 		return;
 	}
-	g_free (path);
 	g_object_ref (folder);
 
 	result = exchange_account_remove_favorite (mse->account, folder);
@@ -2739,16 +2738,19 @@ unsubscribe_folder (MailStub *stub, const char *folder_name)
 	case EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED:
 		mail_stub_return_error (stub, _("Permission denied"));
 		g_object_unref (folder);
+		g_free (path);
 		return;
 
 	default:
 		mail_stub_return_error (stub, _("Generic error"));
 		g_object_unref (folder);
+		g_free (path);
 		return;
 
 	}
 
 	g_object_unref (folder);
+	g_free (path);
 	mail_stub_return_ok (stub);
 }
 
